@@ -1,3 +1,9 @@
+def ASR_ACT_ENABLE(value): pass
+"""
+Enables or disabled automatic screen rotation.
+@since: 2010.06.13
+"""
+
 def ASR_EV_LANDSCAPE(): pass
 """
 Gets emitted when the orientation changes to landscape.
@@ -10,8 +16,3 @@ Gets emitted when the orientation changes to portrait.
 @since: 2009.09
 """
 
-def ASR_ACT_FORCE_LANDSCAPE(value): pass
-"""
-Forces landscape mode.
-@since: 2009.11.22
-"""
