@@ -34,4 +34,11 @@ class AudioInspector(FileInspector):
         entry["Audio.Artist"] = tags.get("ARTIST") or "unspecified"
         entry["Audio.Album"] = tags.get("ALBUM") or entry["Audio.Artist"]
         entry["Audio.Genre"] = tags.get("GENRE") or "unspecified"
+        try:
+            trackno = tags.get("TRACKNUMBER")
+            trackno = trackno.split("/")[0]
+            trackno = int(trackno)
+        except:
+            trackno = 0
+        entry["Audio.Tracknumber"] = trackno
 
