@@ -1,5 +1,4 @@
 from com import Component, MediaOutput, msgs
-from ui.dialog import OptionDialog
 from utils import logging
 
 
@@ -16,7 +15,7 @@ class MediaOutputService(Component):
         Component.__init__(self)
         
         
-    def handle_CORE_EV_APP_STARTED(self):
+    def handle_COM_EV_APP_STARTED(self):
     
         if (self.__outputs):
             self.__current_output = self.__outputs[0]
@@ -54,18 +53,19 @@ class MediaOutputService(Component):
     
         if (isinstance(output, MediaOutput)):
             self.__current_output = output
+            self.emit_message(msgs.MEDIA_ACT_STOP)
 
         elif (output == None):
+            from ui.dialog import OptionDialog
             dlg = OptionDialog("Select Media Renderer")
             for output in self.__outputs:
                 dlg.add_option(None, output.TITLE)
             #end for
             ret = dlg.run()
-            if (ret == 0):
+            if (ret == dlg.RETURN_OK):
                 choice = dlg.get_choice()
                 self.__current_output = self.__outputs[choice]
+                self.emit_message(msgs.MEDIA_ACT_STOP)
             #end if
         #end if
         
-        self.emit_message(msgs.MEDIA_ACT_STOP)
-
