@@ -146,6 +146,23 @@ def CORE_EV_THEME_CHANGED(): pass
 Gets emitted when the theme has changed.
 """
 
+def MEDIA_ACT_PREPARE(f): pass
+"""
+Prepares the given file for loading.
+@since: 2010.09.01
+
+@param f: file object to prepare
+"""
+
+def MEDIA_ACT_LOAD_URI(uri, mimetype = ""): pass
+"""
+Loads the given URI into the appropriate media player.
+Tries to guess the MIME type if none was specified.
+@since: 2010.08.31
+
+@param uri: URI to load
+@param mimetype: mimetype of media format
+"""
 
 def MEDIA_ACT_LOAD(f): pass
 """
@@ -347,6 +364,12 @@ when a thumbnail has been found or was created.
 @param args: variable list of arguments to the callback handler
 """
 
+def THUMBNAIL_EV_LOADING(): pass
+"""
+Gets emitted when the thumbnailer starts loading.
+@since: 2010.08.08
+"""
+
 
 def UI_ACT_FREEZE(): pass
 """
@@ -391,17 +414,6 @@ Displays an info notification.
 @param text: text to display
 """
 
-def UI_ACT_SHOW_MESSAGE(text, subtext, icon): pass
-"""
-Displays an overlay message. The message is displayed until
-L{UI_ACT_HIDE_MESSAGE} is called.
-
-
-@param text: title text
-@param subtext: message text
-@param icon: pixbuf object or C{None}
-"""
-
 def UI_ACT_HIDE_MESSAGE(): pass
 """
 Hides the current overlay message, if there is any.
