@@ -4,6 +4,7 @@ from mediabox import config
 import commands
 import os
 import gobject
+import threading
 import time
 
 
@@ -28,52 +29,50 @@ class TrackerScanner(Component):
             return []
 
 
-    def __get_tracker_music(self, lines):
+    def __get_tracker_list(self):
     
-        lines += self.__get_tracker_files("Music")
-        gobject.idle_add(self.__get_tracker_videos, lines)
-
-
-    def __get_tracker_videos(self, lines):
+        def discover(path, mtime, lock):
+            self.call_service(msgs.FILEINDEX_SVC_DISCOVER, path, mtime)
+            lock.release()
     
+        lines = []
+        lines += self.__get_tracker_files("Music")    
         lines += self.__get_tracker_files("Videos")
-        gobject.idle_add(self.__get_tracker_images, lines)
-
-
-    def __get_tracker_images(self, lines):
-    
         lines += self.__get_tracker_files("Images")
-        gobject.idle_add(self.__process_tracker_files, lines)
 
-
-    def __process_tracker_files(self, lines):
-    
-        now = time.time()
-        while (time.time() < now + 0.05 and lines):
+        lock = threading.Lock()
+        while (lines):
             line = lines.pop(0)
             path = line.strip()
             try:
                 mtime = int(os.path.getmtime(path))
-                self.call_service(msgs.FILEINDEX_SVC_DISCOVER, path, mtime)
             except:
-                pass
+                continue
+                
+            lock.acquire()
+            gobject.idle_add(discover, path, mtime, lock)
+            time.sleep(0.01)
         #end while
-        
-        if (lines):
-            return True
-        else:
-            self.emit_message(msgs.UI_ACT_SHOW_INFO,
-                              "Scanning for media finished.")
-            return False
+  
+        gobject.idle_add(self.emit_message, msgs.UI_ACT_SHOW_INFO,
+                        "Scanning for media finished.")
 
 
     def handle_COM_EV_APP_STARTED(self):
 
         if (config.scan_at_startup()):
-            gobject.idle_add(self.__get_tracker_music, [])
+            t = threading.Thread(target = self.__get_tracker_list)
+            t.setDaemon(True)
+            t.start()    
+
+            #self.emit_message(msgs.UI_ACT_SHOW_INFO,
+            #              "not querying tracker")
 
 
     def handle_FILEINDEX_ACT_SCAN(self):
-    
-        gobject.idle_add(self.__get_tracker_music, [])
+
+        t = threading.Thread(target = self.__get_tracker_list)
+        t.setDaemon(True)
+        t.start()    
+        #gobject.idle_add(self.__get_tracker_music, [])
 
