@@ -2,6 +2,8 @@
 Parser for Ogg tags.
 """
 
+import mapping
+
 
 def _read_tagsoup(fd):
 
@@ -32,6 +34,10 @@ def _parse_tagsoup(soup):
             key = e[:idx]
             #print "  " + key
             value = e[idx + 1:-1]
+            
+            if (key.upper() == "GENRE"):
+                value = mapping.resolve_genre(value)
+
             tags[key.upper()] = value
     #end for
 
