@@ -134,11 +134,9 @@ class File(object):
 
         self.thumbnailer_param = None
         
-        
         self.icon = ""
         """
-        may contain the path of an icon image (deprecated) or a pixbuf that can
-        be used instead of a thumbnail. the image should be of a proper size
+        may contain the path of an icon image
         @since: 0.96.4
         """        
         
@@ -173,8 +171,8 @@ class File(object):
     def __cmp__(self, other):
     
         if (other):
-            return cmp((self.index, self.name.upper(), self.full_path),
-                       (other.index, other.name.upper(), other.full_path))
+            return cmp((self.comparable, self.name.upper(), self.full_path),
+                       (other.comparable, other.name.upper(), other.full_path))
         else:
             return 1
 
@@ -341,6 +339,12 @@ class File(object):
         return self.__device.get_file_actions(self, f)
 
 
+    def get_bulk_actions(self):
+        
+        return self.__device.get_bulk_actions(self)
+
+
+
     def get_children(self):
         """
         Returns a list of children of this folder.
